package com.xkrs.service;

import com.xkrs.model.entity.FirePointEntity;
import com.xkrs.model.entity.ShanDongFirePointEntity;
import com.xkrs.model.qo.FirePointQo;
import com.xkrs.model.vo.AppTaskBodyVo;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * @author XinYi Song
 */
public interface FirePointService {

    /**
     * 添加火点信息
     *
     * @param firePointQo
     * @return
     */
    FirePointEntity insertFirePoint(FirePointQo firePointQo);

    /**
     * 添加火点信息
     *
     * @param firePointQo
     * @return
     */
    ShanDongFirePointEntity insertFirePointChannelTwo(FirePointQo firePointQo);

    /**
     * 查询今天的火点信息
     *
     * @param
     * @return
     */
    List<FirePointEntity> selectTodayFirePoint(String countyCode);

    /**
     * 根据火点编码修改火点的状态（预警）
     *
     * @param fireCode
     * @param fireType
     * @param token
     * @return
     */
    String updateTypeByFireCode(String fireCode, String fireType, String token);

    /**
     * 提交核查任务信息
     *
     * @param files
     * @param appTaskBodyVo
     * @return
     * @throws IOException
     */
    String insertAppTask(MultipartFile[] files, AppTaskBodyVo appTaskBodyVo) throws IOException;

    /**
     * 根据火点编码查询任务信息
     *
     * @param fireCode
     * @param
     * @return
     * @throws Exception
     */
    String selectAppTask(String fireCode) throws Exception;

    /**
     * 查询近一周天的火点信息
     *
     * @return
     */
    List<FirePointEntity> selectFirePointBetweenSeven();

    /**
     * 查询近一个月的火点信息
     *
     * @return
     */
    List<FirePointEntity> selectFirePointByMonth(String countyCode);

    /**
     * 查询近一个月的火点数量
     *
     * @return
     */
    String selectFirePointNumMonth();

    /**
     * 查询近一天的火点数量
     *
     * @return
     */
    String selectFirePointNumDay();

    /**
     * 查询
     *
     * @return
     */
    String selectFirePointNumWeek();

    /**
     * 更新火点的街道编号数据
     *
     * @return
     */
    String updateFirePointStreetCode();

    /**
     * 根据火点编号更新审核状态
     * 操作1：将火点编号对应的火点从山东火点表转存到火点表
     * 操作2：将山东火点表中的这个火点的审核状态更新
     */
    String updateVerifyStateByFireCode(String fireCode, String verifyState);

    /**
     * download vip user's fire point
     *
     * @param request
     * @param response
     */
    String downloadVipUserFilePoint(HttpServletRequest request, HttpServletResponse response);
}
