package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.ConfigGlobalFirePointDao;
import com.xkrs.model.entity.ConfigGlobalFirePointEntity;
import com.xkrs.service.ConfigGlobalFirePointService;
import com.xkrs.utils.ConfigConstant;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 火情信息全局配置服务
 */
@Service
public class ConfigGlobalFirePointServiceImpl implements ConfigGlobalFirePointService {

    private final Locale locale = LocaleContextHolder.getLocale();

    /**
     * 火情信息全局配置信息
     */
    @Resource
    private ConfigGlobalFirePointDao configGlobalFirePointDao;

    @Override
    public boolean todayAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalFirePointDao.findAll().get(0).getTodayAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public boolean historyAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalFirePointDao.findAll().get(0).getHistoryAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public boolean statisticsAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalFirePointDao.findAll().get(0).getStatisticsAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public boolean navigateAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalFirePointDao.findAll().get(0).getNavigateAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public ConfigGlobalFirePointEntity findFirePointGlobalConfig() {
        try {
            return configGlobalFirePointDao.findAll().get(0);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    @Override
    public String configGlobalFirePoint(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long todayAbleWhenExpired = configMap.get("todayAbleWhenExpired");
        Long historyAbleWhenExpired = configMap.get("historyAbleWhenExpired");
        Long statisticsAbleWhenExpired = configMap.get("statisticsAbleWhenExpired");
        Long navigateAbleWhenExpired = configMap.get("navigateAbleWhenExpired");
        List<ConfigGlobalFirePointEntity> configGlobalFirePointEntityList = configGlobalFirePointDao.findAll();
        if (configGlobalFirePointEntityList.isEmpty()) {
            ConfigGlobalFirePointEntity configGlobalFirePointEntity = new ConfigGlobalFirePointEntity();
            configGlobalFirePointEntity.setTodayAbleWhenExpired(todayAbleWhenExpired);
            configGlobalFirePointEntity.setHistoryAbleWhenExpired(historyAbleWhenExpired);
            configGlobalFirePointEntity.setStatisticsAbleWhenExpired(statisticsAbleWhenExpired);
            configGlobalFirePointEntity.setNavigateAbleWhenExpired(navigateAbleWhenExpired);
            configGlobalFirePointDao.save(configGlobalFirePointEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalFirePointEntity configGlobalFirePointEntity = configGlobalFirePointEntityList.get(0);
        if (todayAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getTodayAbleWhenExpired() == null || configGlobalFirePointEntity.getTodayAbleWhenExpired().longValue() != todayAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setTodayAbleWhenExpired(todayAbleWhenExpired);
            }
        }
        if (historyAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getHistoryAbleWhenExpired() == null || configGlobalFirePointEntity.getHistoryAbleWhenExpired().longValue() != historyAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setHistoryAbleWhenExpired(historyAbleWhenExpired);
            }
        }
        if (statisticsAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getStatisticsAbleWhenExpired() == null || configGlobalFirePointEntity.getStatisticsAbleWhenExpired().longValue() != statisticsAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setStatisticsAbleWhenExpired(statisticsAbleWhenExpired);
            }
        }
        if (navigateAbleWhenExpired != null) {
            if (configGlobalFirePointEntity.getNavigateAbleWhenExpired() == null || configGlobalFirePointEntity.getNavigateAbleWhenExpired().longValue() != navigateAbleWhenExpired.longValue()) {
                configGlobalFirePointEntity.setNavigateAbleWhenExpired(navigateAbleWhenExpired);
            }
        }
        configGlobalFirePointDao.save(configGlobalFirePointEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }

}
