package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.ConfigGlobalSMSDao;
import com.xkrs.model.entity.ConfigGlobalSMSEntity;
import com.xkrs.service.ConfigGlobalSMSService;
import com.xkrs.utils.ConfigConstant;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 短信全局配置服务
 */
@Service
public class ConfigGlobalSMSServiceImpl implements ConfigGlobalSMSService {

    private final Locale locale = LocaleContextHolder.getLocale();

    /**
     * 短信全局配置信息
     */
    @Resource
    private ConfigGlobalSMSDao configGlobalSMSDao;

    @Override
    public boolean smsAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalSMSDao.findAll().get(0).getSmsAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public boolean proAnAbleBeforeExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalSMSDao.findAll().get(0).getProAnAbleBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public long proAnDayBeforeExpired() {
        try {
            return configGlobalSMSDao.findAll().get(0).getProAnDayBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0L;
    }

    @Override
    public boolean cityAnAbleBeforeExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalSMSDao.findAll().get(0).getCityAnAbleBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public long cityAnDayBeforeExpired() {
        try {
            return configGlobalSMSDao.findAll().get(0).getCityAnDayBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0L;
    }

    @Override
    public boolean countyAnAbleBeforeExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalSMSDao.findAll().get(0).getCountyAnAbleBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public long countyAnDayBeforeExpired() {
        try {
            return configGlobalSMSDao.findAll().get(0).getCountyAnDayBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0L;
    }

    @Override
    public boolean streetAnAbleBeforeExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalSMSDao.findAll().get(0).getStreetAnAbleBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public long streetAnDayBeforeExpired() {
        try {
            return configGlobalSMSDao.findAll().get(0).getStreetAnDayBeforeExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0L;
    }

    @Override
    public String configGlobalSMS(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long smsAbleWhenExpired = configMap.get("smsAbleWhenExpired");
        Long proAnAbleBeforeExpired = configMap.get("proAnAbleBeforeExpired");
        Long proAnDayBeforeExpired = configMap.get("proAnDayBeforeExpired");
        Long cityAnAbleBeforeExpired = configMap.get("cityAnAbleBeforeExpired");
        Long cityAnDayBeforeExpired = configMap.get("cityAnDayBeforeExpired");
        Long countyAnAbleBeforeExpired = configMap.get("countyAnAbleBeforeExpired");
        Long countyAnDayBeforeExpired = configMap.get("countyAnDayBeforeExpired");
        Long streetAnAbleBeforeExpired = configMap.get("streetAnAbleBeforeExpired");
        Long streetAnDayBeforeExpired = configMap.get("streetAnDayBeforeExpired");
        List<ConfigGlobalSMSEntity> configGlobalSMSEntityList = configGlobalSMSDao.findAll();
        if (configGlobalSMSEntityList.isEmpty()) {
            ConfigGlobalSMSEntity configGlobalSMSEntity = new ConfigGlobalSMSEntity();
            configGlobalSMSEntity.setSmsAbleWhenExpired(smsAbleWhenExpired);
            configGlobalSMSEntity.setProAnAbleBeforeExpired(proAnAbleBeforeExpired);
            configGlobalSMSEntity.setProAnDayBeforeExpired(proAnDayBeforeExpired);
            configGlobalSMSEntity.setCityAnAbleBeforeExpired(cityAnAbleBeforeExpired);
            configGlobalSMSEntity.setCityAnDayBeforeExpired(cityAnDayBeforeExpired);
            configGlobalSMSEntity.setCountyAnAbleBeforeExpired(countyAnAbleBeforeExpired);
            configGlobalSMSEntity.setCountyAnDayBeforeExpired(countyAnDayBeforeExpired);
            configGlobalSMSEntity.setStreetAnAbleBeforeExpired(streetAnAbleBeforeExpired);
            configGlobalSMSEntity.setStreetAnDayBeforeExpired(streetAnDayBeforeExpired);
            configGlobalSMSDao.save(configGlobalSMSEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalSMSEntity configGlobalSMSEntity = configGlobalSMSEntityList.get(0);
        if (smsAbleWhenExpired != null) {
            if (configGlobalSMSEntity.getSmsAbleWhenExpired() == null || configGlobalSMSEntity.getSmsAbleWhenExpired().longValue() != smsAbleWhenExpired.longValue()) {
                configGlobalSMSEntity.setSmsAbleWhenExpired(smsAbleWhenExpired);
            }
        }
        if (proAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getProAnAbleBeforeExpired() == null || configGlobalSMSEntity.getProAnAbleBeforeExpired().longValue() != proAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setProAnAbleBeforeExpired(proAnAbleBeforeExpired);
            }
        }
        if (proAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getProAnDayBeforeExpired() == null || configGlobalSMSEntity.getProAnDayBeforeExpired().longValue() != proAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setProAnDayBeforeExpired(proAnDayBeforeExpired);
            }
        }
        if (cityAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getCityAnAbleBeforeExpired() == null || configGlobalSMSEntity.getCityAnAbleBeforeExpired().longValue() != cityAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCityAnAbleBeforeExpired(cityAnAbleBeforeExpired);
            }
        }
        if (cityAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getCityAnDayBeforeExpired() == null || configGlobalSMSEntity.getCityAnDayBeforeExpired().longValue() != cityAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCityAnDayBeforeExpired(cityAnDayBeforeExpired);
            }
        }
        if (countyAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getCountyAnAbleBeforeExpired() == null || configGlobalSMSEntity.getCountyAnAbleBeforeExpired().longValue() != countyAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCountyAnAbleBeforeExpired(countyAnAbleBeforeExpired);
            }
        }
        if (countyAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getCountyAnDayBeforeExpired() == null || configGlobalSMSEntity.getCountyAnDayBeforeExpired().longValue() != countyAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setCountyAnDayBeforeExpired(countyAnDayBeforeExpired);
            }
        }
        if (streetAnAbleBeforeExpired != null) {
            if (configGlobalSMSEntity.getStreetAnAbleBeforeExpired() == null || configGlobalSMSEntity.getStreetAnAbleBeforeExpired().longValue() != streetAnAbleBeforeExpired.longValue()) {
                configGlobalSMSEntity.setStreetAnAbleBeforeExpired(streetAnAbleBeforeExpired);
            }
        }
        if (streetAnDayBeforeExpired != null) {
            if (configGlobalSMSEntity.getStreetAnDayBeforeExpired() == null || configGlobalSMSEntity.getStreetAnDayBeforeExpired().longValue() != streetAnDayBeforeExpired.longValue()) {
                configGlobalSMSEntity.setStreetAnDayBeforeExpired(streetAnDayBeforeExpired);
            }
        }
        configGlobalSMSDao.save(configGlobalSMSEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }
}
