package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.ConfigGlobalUserDao;
import com.xkrs.model.entity.ConfigGlobalUserEntity;
import com.xkrs.service.ConfigGlobalUserService;
import com.xkrs.utils.ConfigConstant;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 用户全局配置服务
 */
@Service
public class ConfigGlobalUserServiceImpl implements ConfigGlobalUserService {

    private final Locale locale = LocaleContextHolder.getLocale();

    /**
     * 用户全局配置信息
     */
    @Resource
    private ConfigGlobalUserDao configGlobalUserDao;

    @Override
    public boolean loginAbleWhenExpired() {
        try {
            return ConfigConstant.STATE_ACTIVE.longValue() == configGlobalUserDao.findAll().get(0).getLoginAbleWhenExpired().longValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    @Override
    public String configGlobalUser(Map<String, Long> configMap) {
        if (configMap == null) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_NULL, "配置失败", locale);
        }
        Long loginAbleWhenExpired = configMap.get("loginAbleWhenExpired");
        List<ConfigGlobalUserEntity> configGlobalUserEntityList = configGlobalUserDao.findAll();
        if (configGlobalUserEntityList.isEmpty()) {
            ConfigGlobalUserEntity configGlobalUserEntity = new ConfigGlobalUserEntity();
            configGlobalUserEntity.setLoginAbleWhenExpired(loginAbleWhenExpired);
            configGlobalUserDao.save(configGlobalUserEntity);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
        }
        ConfigGlobalUserEntity configGlobalUserEntity = configGlobalUserEntityList.get(0);
        if (loginAbleWhenExpired != null) {
            if (configGlobalUserEntity.getLoginAbleWhenExpired() == null || configGlobalUserEntity.getLoginAbleWhenExpired().longValue() != loginAbleWhenExpired.longValue()) {
                configGlobalUserEntity.setLoginAbleWhenExpired(loginAbleWhenExpired);
            }
        }
        configGlobalUserDao.save(configGlobalUserEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "配置成功", locale);
    }

}
